@@ -16,7 +16,6 @@ import (
 	"net"
 	"os"
 	"sort"
-	"strconv"
 	"strings"
 	"time"
 
@@ -231,13 +230,6 @@ func (s *Session) Exchange(conn net.Conn) (stats TrafficStats, err error) {
 		return stats, nil
 	}
 
-	// Experimental support for fetching messages only for auxiliary addresses (not mycall).
-	// Ref https://groups.google.com/g/pat-users/c/5G1JIEyFXe4
-	if t, _ := strconv.ParseBool(os.Getenv("FW_AUX_ONLY_EXPERIMENT")); t && len(s.localFW) > 1 {
-		s.localFW = s.localFW[1:]
-		s.log.Printf("FW_AUX_ONLY_EXPERIMENT: Requesting messages for %v", s.localFW)
-	}
-
 	// The given conn should always be closed after returning from this method.
 	// If an error occurred, echo it to the remote.
 	defer func() {
